This crate contains kube-rs compatible bindings for Kubernetes custom resources for the apisix.apache.org group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
apisix.apache.org/v2
ApisixClusterConfigApisixConsumerApisixGlobalRuleApisixPluginConfigApisixRouteApisixTlsApisixUpstream